@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Mailer.py 10456 2017-11-07 09:20:54Z David $
+# $Id: Mailer.py 10657 2017-12-18 09:18:37Z David $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -13,7 +13,7 @@
 #
 # $Author: David $ (Last)
 # $Date: 2013-01-30 12:13:45 +0800$
-# $Revision: 10456 $
+# $Revision: 10657 $
 
 import os
 import random
@@ -265,7 +265,9 @@ class CloudMailer(Mailer):
         Get content of newsletter's header.
         """
         try:
-            header = Header.objects.all()[0]
+            header = self.newsletter.header
+            if not header:
+                header = Header.objects.all()[0]
             _content = self._replaceContent(header.content)
             return Template(_content)
         except:
@@ -276,7 +278,9 @@ class CloudMailer(Mailer):
         Get content of newsletter's footer.
         """
         try:
-            footer = Footer.objects.all()[0]
+            footer = self.newsletter.footer
+            if not footer:
+                footer = Footer.objects.all()[0]
             _content = self._replaceContent(footer.content)
             return Template(_content)
         except:
