@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 10388 2017-10-21 15:16:00Z David $
+# $Id: views.py 10440 2017-11-05 12:25:48Z David $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,11 +12,12 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-10-21 23:16:00 +0800 (Sat, 21 Oct 2017) $
-# $Revision: 10388 $
+# $Date: 2017-11-05 20:25:48 +0800 (Sun, 05 Nov 2017) $
+# $Revision: 10440 $
 
 import re
 import time
+import json
 
 from urlparse import urljoin
 
@@ -306,8 +307,9 @@ from django.views.decorators.csrf import csrf_exempt
 
 from Iuppiter.Json import serializer
 
-def recordStatus(messageId, destination, status):
+def recordStatus(messageId, destination, status, messageStr):
     amazonLogger.info("START: Start record.")
+    
     try:
         amazonLogger.info(
             "messageId=%s, destination=%s, status=%s" %
@@ -330,11 +332,21 @@ def recordStatus(messageId, destination, status):
         if obj:
             newsletter = obj.newsletter
             contact = obj.contact
+            
             for contact in Contact.objects.filter(email__in=destination):
                 ContactMailingStatus.objects.create(
                     newsletter=newsletter,
                     contact=contact,
-                    status=status)
+                    status=status,
+                )
+
+            cloudSrv.recordSendInformation(
+                newsletter, 
+                contact, 
+                messageId, 
+                messageStr
+            )
+
             amazonLogger.info("SUCCESS: Record success.")
         else:
             amazonLogger.error("PASS: Not matched, record pass.")
@@ -344,14 +356,14 @@ def recordStatus(messageId, destination, status):
     finally:
         amazonLogger.info("END: Record end.")
 
-def recordBouncedStatus(messageId, destination):
-    recordStatus(messageId, destination, ContactMailingStatus.BOUNCED)
+def recordBouncedStatus(messageId, destination, messageStr):
+    recordStatus(messageId, destination, ContactMailingStatus.BOUNCED, messageStr)
 
-def recordRejectedStatus(messageId, destination):
-    recordStatus(messageId, destination, ContactMailingStatus.REJECTED)
+def recordRejectedStatus(messageId, destination, messageStr):
+    recordStatus(messageId, destination, ContactMailingStatus.REJECTED, messageStr)
 
-def recordComplaintStatus(messageId, destination):
-    recordStatus(messageId, destination, ContactMailingStatus.COMPLAINT)
+def recordComplaintStatus(messageId, destination, messageStr):
+    recordStatus(messageId, destination, ContactMailingStatus.COMPLAINT, messageStr)
 
 def isBounceType(bounceType, bounceSubType):
     if bounceType == 'Undetermined' and bounceSubType == 'Undetermined':
@@ -440,13 +452,27 @@ def handleSNS(request):
             notificationType = message.get('notificationType', '')
 
             amazonLogger.info("Message type: %s" % notificationType)
-
             bounceDict = message.get('bounce', '')
+            complaintDict = message.get('complaint', '')
             mail = message.get('mail', {})
             destination = mail.get('destination', [])
             messageId = mail.get('messageId', '')
-            
 
+            if re.search(r'\"(.*?)\"', str(message)):
+                escapeStr = re.search(r'\"(.*?)\"', str(message)).group(1)
+                messageStr = re.sub(r'\"(.*?)\"', r'$$$$$', str(message))
+                messageStr = re.sub(r'\'', r'"', messageStr)
+                messageStr = messageStr.replace(
+                    '$$$$$', "\"" + escapeStr + "\"")
+                amazonLogger.info(messageStr)
+            else:
+                messageStr = str(message).replace('\'', '"')
+                
+            messageStr = json.dumps(
+                json.loads(messageStr), 
+                indent=4, 
+                sort_keys=True
+            )
             if notificationType == 'Bounce': # Bounced.
                 # Get bounce's type.
                 bounceType = bounceDict.get('bounceType', '')
@@ -455,16 +481,16 @@ def handleSNS(request):
                 if isBounce:
                     # record!
                     amazonLogger.info("Got bounce, need record...")
-                    recordBouncedStatus(messageId, destination)
+                    recordBouncedStatus(messageId, destination, messageStr)
                 else:
                     # record!
                     amazonLogger.info("Got rejected, need record...")
-                    recordRejectedStatus(messageId, destination)
+                    recordRejectedStatus(messageId, destination, messageStr)
 
             elif notificationType == 'Complaint': # Complaints.
                 # Record.
                 amazonLogger.info("Got complaint, need record...")
-                recordComplaintStatus(messageId, destination)
+                recordComplaintStatus(messageId, destination, messageStr)
 
             elif notificationType == 'Delivery': # Deliveries.
                 amazonLogger.info("Got delivery, check if need record...")
