@@ -12,7 +12,7 @@
 # limitations under the License.
 #
 # $Author: Judy $
-# $Date: 2016-03-18 20:59:58 +0800 (五, 18  3 2016) $
+# $Date: 2016-03-18 20:59:58 +0800 (Fri, 18 Mar 2016) $
 # $Revision: 9594 $
 
 from django.db import models
@@ -21,10 +21,10 @@ from django.utils.translation import ugettext as _
 
 from Iuppiter.Model import BaseModelMixin
 
-# from Theophrastus.models import Newsletter
-from emencia.django.newsletter.models import Newsletter
+from Theophrastus.models import Newsletter, MailingList
 
-class Group(models.Model):
+
+class Group(models.Model, BaseModelMixin):
     name = models.CharField(_('name'), max_length=255)
 
     newsletters = models.ManyToManyField(
@@ -77,7 +77,7 @@ class Group(models.Model):
         verbose_name = _('group')
         verbose_name_plural = _('groups')
 
-class App(models.Model):
+class App(models.Model, BaseModelMixin):
     name = models.CharField(max_length=255, verbose_name=_('Name'))
     user = models.ForeignKey(User, verbose_name=_('User'))
     groups = models.ManyToManyField(Group, related_name='groups', null=True)
@@ -91,7 +91,15 @@ class App(models.Model):
         verbose_name = _('app')
         verbose_name_plural = _('apps')
 
-class GroupMappingTable(models.Model):
+class AppMailingList(models.Model):
+    app = models.ForeignKey(App)
+    mailingList = models.ForeignKey(MailingList)
+
+class AppNewsletter(models.Model):
+    app = models.ForeignKey(App)
+    newsletter = models.ForeignKey(Newsletter)
+
+class GroupMappingTable(models.Model, BaseModelMixin):
 
     KEYWORD = 0
     REGULAR_EXPRESSION = 1
