@@ -32,6 +32,9 @@ from Iuppiter.Encoding import _unicode
 from Iuppiter.Logging import createDebugLogger
 
 from Theophrastus.integration.service import IntegrationService
+from Theophrastus.integration.models import(
+    AppMailingList, AppNewsletter
+)
 from Theophrastus.statistics.StatisticsHandler import getStatisticsTotalData
 from Theophrastus.statistics.StatisticsHandler import getStatisticsTotalRateData
 from Theophrastus.statistics.StatisticsHandler import getSubscriberHistory
@@ -318,6 +321,12 @@ def mail(request):
             headerSender=headerSender, headerReply=headerReply,
             attachments=attachments, async=async)
         group.newsletters.add(newsletter)
+        AppNewsletter.objects.create(newsletter=newsletter, app=app)
+        AppMailingList.objects.create(
+            mailingList=newsletter.mailing_list,
+            app=app
+        )
+
         logger.debug('[createMail]_SUSSESS: newsletter<%d>' % newsletter.id)
 
         if async:
